import requests


def http_get(**params):
    res = requests.get(**params)
    return res


def http_post(**params):
    res = requests.post(**params)
    return res


if __name__ == "__main__":
    print('### bone http ###')



import pyodbc


def sql_query_rows(connection_string, query,
                   query_size=100000):
    """Return dict list."""
    with pyodbc.connect(connection_string) as cnxn:
        cursor = cnxn.cursor()
        cursor.execute(query)
        rows = cursor.fetchmany(query_size)
        full_query_result = {'description': cursor.description, 'rows': rows}
        return _extract_dict_list_from_sql_query_result(full_query_result)


def sql_query_cell(connection_string, query):
    return sql_execute_query(connection_string, query)


def sql_execute_query(connection_string, query):
    with pyodbc.connect(connection_string) as cnxn:
        cursor = cnxn.cursor()
        cursor.execute(query)
        res = cursor.fetchone()
        cursor.commit()
        return res[0]


def _extract_dict_list_from_sql_query_result(full_query_result):
    dict_rows = []
    if full_query_result['rows']:
        for query_row in full_query_result['rows']:
            row = {}
            for i in range(len(full_query_result['description'])):
                row[full_query_result['description'][i][0]] = query_row[i]
            dict_rows.append(row)
    return dict_rows


if __name__ == "__main__":
    print('### bon sql ###')



from package.local.bon_env import \
    mkpath, mkdownloadspath, mkdir, \
    read_string, read_string_default, \
    read_json, read_json_default, \
    read_lines, \
    read_csv_list, read_csv_list_default, \
    read_csv_dict_list, read_csv_dict_list_default, \
    write_string, write_string_default, \
    write_json, write_json_default, \
    write_lines, append_line, \
    write_file, \
    write_csv, write_csv_default, \
    transform_parquet_to_json, \
    transform_parquet_to_json_default
from package.local.bon_env import \
    plant_env, check_env, clean_up_env

from package.processor.bon_string import \
    regex_modify_string

from package.remote.bon_http import \
    http_get, http_post

from package.storage.bon_az_blob import \
    azure_blob_get, azure_blob_upload
from package.storage.bon_sql import \
    sql_query_rows, sql_query_cell, sql_execute_query



import setuptools
from pipenv.project import Project
from pipenv.utils import convert_deps_to_pip

with open("README.md", "r") as fh:
    long_description = fh.read()

pfile = Project(chdir=False).parsed_pipfile
install_requires = convert_deps_to_pip(pfile['packages'], r=False)

setuptools.setup(
    name="bonbon",
    version="0.0.6",
    author="Lby",
    author_email="lbyxiafei@gmail.com",
    description="Bonbon.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/lbyxiafei/bonbon",
    install_requires=install_requires,
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
